(function (global, factory) {
	typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('@angular/core'), require('@angular/common'), require('@angular/forms'), require('@angular/platform-browser')) :
	typeof define === 'function' && define.amd ? define(['exports', '@angular/core', '@angular/common', '@angular/forms', '@angular/platform-browser'], factory) :
	(factory((global['ngx-myform'] = global['ngx-myform'] || {}),global._angular_core,global._angular_common,global._angular_forms,global._angular_platformBrowser));
}(this, (function (exports,_angular_core,_angular_common,_angular_forms,_angular_platformBrowser) { 'use strict';

var FormService = (function () {
    /**
     * @param {?} fb
     */
    function FormService(fb) {
        this.fb = fb;
    }
    /**
     * @param {?=} models
     * @return {?}
     */
    FormService.prototype._createFormGroupItem = function (models) {
        var _this = this;
        if (models === void 0) { models = []; }
        return models.reduce(function (current, model) {
            var /** @type {?} */ item = {};
            var /** @type {?} */ sub_group_item = {};
            switch (model.type) {
                case 'group':
                    sub_group_item = _this._createFormGroupItem(model.options.group);
                    item = (_a = {},
                        _a[model.options.id] = _this.fb.group(sub_group_item, {
                            validator: _this._getValidators(model.options.validators),
                            asyncValidator: _this._getAsyncValidators(model.options.asyncValidators)
                        }),
                        _a);
                    break;
                case 'checkboxgroup':
                    var /** @type {?} */ checkbox_group_options = model.options.options ? model.options.options : [];
                    sub_group_item = checkbox_group_options.reduce(function (_current, option) {
                        return Object.assign(_current, (_a = {},
                            _a[option.id] = new _angular_forms.FormControl({ value: option.value, disabled: option.disabled }),
                            _a));
                        var _a;
                    }, {});
                    item = (_b = {},
                        _b[model.options.id] = _this.fb.group(sub_group_item, {
                            validator: _this._getValidators(model.options.validators),
                            asyncValidator: _this._getAsyncValidators(model.options.asyncValidators)
                        }),
                        _b);
                    break;
                default:
                    item = (_c = {}, _c[model.options.id] = new _angular_forms.FormControl({ value: model.options.value, disabled: model.options.disabled }, _this._getValidators(model.options.validators), _this._getAsyncValidators(model.options.asyncValidators)), _c);
                    break;
            }
            return Object.assign(current, item);
            var _a, _b, _c;
        }, {});
    };
    /**
     * @param {?} config
     * @return {?}
     */
    FormService.prototype._getValidators = function (config) {
        var /** @type {?} */ validators_array = config ? config.map(function (item) {
            return item.validator;
        }) : [];
        return _angular_forms.Validators.compose(validators_array);
    };
    /**
     * @param {?} config
     * @return {?}
     */
    FormService.prototype._getAsyncValidators = function (config) {
        var /** @type {?} */ validators_array = config ? config.map(function (item) {
            return item.validator;
        }) : [];
        return _angular_forms.Validators.composeAsync(validators_array);
    };
    /**
     * @param {?} models
     * @return {?}
     */
    FormService.prototype.createFormGroup = function (models) {
        var /** @type {?} */ items = this._createFormGroupItem(models);
        return this.fb.group(items);
    };
    return FormService;
}());
FormService.decorators = [
    { type: _angular_core.Injectable },
];
/**
 * @nocollapse
 */
FormService.ctorParameters = function () { return [
    { type: _angular_forms.FormBuilder, },
]; };

var FunctionalService = (function () {
    /**
     * @param {?} fs
     */
    function FunctionalService(fs) {
        this.fs = fs;
    }
    /**
     * @param {?} fg
     * @param {?} models
     * @return {?}
     */
    FunctionalService.prototype.setFormErrorMessage = function (fg, models) {
        var _this = this;
        Object.keys(fg.controls).map(function (key) {
            var /** @type {?} */ model = models.find(function (_model) { return _model.options.id === key; });
            switch (model.type) {
                case 'group':
                    var /** @type {?} */ group_fg = (fg.get(model.options.id));
                    var /** @type {?} */ sub_models = (model.options.group);
                    _this.setFormErrorMessage(group_fg, sub_models);
                    break;
                default:
                    _this.setModelErrorMessage(fg, model);
            }
        });
    };
    /**
     * @param {?} fg
     * @param {?} model
     * @return {?}
     */
    FunctionalService.prototype.setModelErrorMessage = function (fg, model) {
        try {
            model.errorMessage = '';
            var /** @type {?} */ control = fg.get(model.options.id);
            // combine async and sync validators's messages
            var /** @type {?} */ sync_validators = model.options.validators;
            var /** @type {?} */ sync_m = void 0, /** @type {?} */ async_m = void 0;
            if (!sync_validators) {
                sync_m = {};
            }
            else {
                sync_m = sync_validators.reduce(function (a, b) {
                    return Object.assign(a, (_a = {}, _a[b.key] = b.message ? b.message : ' ', _a));
                    var _a;
                }, {});
            }
            var /** @type {?} */ async_validators = model.options.asyncValidators;
            if (!async_validators) {
                async_m = {};
            }
            else {
                async_m = async_validators.reduce(function (a, b) {
                    return Object.assign(a, (_a = {}, _a[b.key] = b.message ? b.message : ' ', _a));
                    var _a;
                }, {});
            }
            var /** @type {?} */ m = Object.assign(sync_m, async_m);
            var /** @type {?} */ errors = control.errors;
            for (var /** @type {?} */ key in errors) {
                if (errors.hasOwnProperty(key)) {
                    if (!m[key]) {
                        // tslint:disable-next-line:max-line-length
                        console.error('validator config error! the key must be same as the applied Validator\'s key!\n the key is : \'' + key + '\' ; please check it!');
                    }
                    model.errorMessage += m[key] + ' ';
                }
            }
        }
        catch (e) {
            // throw e;
        }
    };
    /**
     * @param {?} fg
     * @return {?}
     */
    FunctionalService.prototype.checkAllInvalidAndDirty = function (fg) {
        var _this = this;
        return Object.keys(fg.controls).every(function (key) {
            if (fg.controls[key].constructor.name === 'FormGroup') {
                return _this.checkAllInvalidAndDirty(/** @type {?} */ (fg.controls[key]));
            }
            else {
                return fg.controls[key].valid ? true : (fg.controls[key].dirty && fg.controls[key].invalid);
            }
        });
    };
    return FunctionalService;
}());
FunctionalService.decorators = [
    { type: _angular_core.Injectable },
];
/**
 * @nocollapse
 */
FunctionalService.ctorParameters = function () { return [
    { type: FormService, },
]; };

var ModelAttributesDirective = (function () {
    /**
     * @param {?} renderer
     * @param {?} el
     */
    function ModelAttributesDirective(renderer, el) {
        this.renderer = renderer;
        this.el = el;
    }
    /**
     * @param {?} changes
     * @return {?}
     */
    ModelAttributesDirective.prototype.ngOnChanges = function (changes) {
        if (changes['modelAttributes']) {
            for (var /** @type {?} */ key in this.modelAttributes) {
                if (this.modelAttributes.hasOwnProperty(key)) {
                    var /** @type {?} */ value = this.modelAttributes[key];
                    if (key.toLowerCase() === 'disabled' || key.toLowerCase() === 'value') {
                        return;
                    }
                    else {
                        this.renderer.setAttribute(this.el.nativeElement, key, value);
                    }
                }
            }
        }
    };
    return ModelAttributesDirective;
}());
ModelAttributesDirective.decorators = [
    { type: _angular_core.Directive, args: [{ selector: '[modelAttributes]' },] },
];
/**
 * @nocollapse
 */
ModelAttributesDirective.ctorParameters = function () { return [
    { type: _angular_core.Renderer2, },
    { type: _angular_core.ElementRef, },
]; };
ModelAttributesDirective.propDecorators = {
    'modelAttributes': [{ type: _angular_core.Input },],
};

var ModelEventsDirective = (function () {
    /**
     * @param {?} renderer
     * @param {?} el
     */
    function ModelEventsDirective(renderer, el) {
        this.renderer = renderer;
        this.el = el;
    }
    /**
     * @param {?} changes
     * @return {?}
     */
    ModelEventsDirective.prototype.ngOnChanges = function (changes) {
        if (changes['modelEvents']) {
            for (var /** @type {?} */ key in this.modelEvents) {
                if (this.modelEvents.hasOwnProperty(key)) {
                    this.renderer.listen(this.el.nativeElement, key, this.modelEvents[key]);
                }
            }
        }
    };
    return ModelEventsDirective;
}());
ModelEventsDirective.decorators = [
    { type: _angular_core.Directive, args: [{ selector: '[modelEvents]' },] },
];
/**
 * @nocollapse
 */
ModelEventsDirective.ctorParameters = function () { return [
    { type: _angular_core.Renderer2, },
    { type: _angular_core.ElementRef, },
]; };
ModelEventsDirective.propDecorators = {
    'modelEvents': [{ type: _angular_core.Input },],
};

var SanitizeHtmlPipe = (function () {
    /**
     * @param {?} _sanitizer
     */
    function SanitizeHtmlPipe(_sanitizer) {
        this._sanitizer = _sanitizer;
    }
    /**
     * @param {?} _value
     * @return {?}
     */
    SanitizeHtmlPipe.prototype.transform = function (_value) {
        if (!_value) {
            return '';
        }
        else {
            return this._sanitizer.bypassSecurityTrustHtml(_value);
        }
    };
    return SanitizeHtmlPipe;
}());
SanitizeHtmlPipe.decorators = [
    { type: _angular_core.Pipe, args: [{
                name: 'sanitizeHtml'
            },] },
];
/**
 * @nocollapse
 */
SanitizeHtmlPipe.ctorParameters = function () { return [
    { type: _angular_platformBrowser.DomSanitizer, },
]; };

var NgxBootstrapControlComponent = (function () {
    /**
     * @param {?} fns
     * @param {?} renderer
     * @param {?} el
     */
    function NgxBootstrapControlComponent(fns, renderer, el) {
        this.fns = fns;
        this.renderer = renderer;
        this.el = el;
    }
    /**
     * @return {?}
     */
    NgxBootstrapControlComponent.prototype.ngOnInit = function () {
        // combine global class and individual
        var /** @type {?} */ individual_wrappers_class = this.model.options.wrappersClass || {};
        var /** @type {?} */ global_wrappers_class = this.globalWrappersClass || {};
        this.mergedWrappersClass = this.mergeWrappersClass(individual_wrappers_class, global_wrappers_class);
        {
            this.renderer.setProperty(this.el.nativeElement, 'multiple', 'multiple');
        }
        this.onStatusChanges();
    };
    /**
     * @return {?}
     */
    NgxBootstrapControlComponent.prototype.ngOnDestroy = function () {
        this._subscr.unsubscribe();
    };
    /**
     * @return {?}
     */
    NgxBootstrapControlComponent.prototype.onStatusChanges = function () {
        var _this = this;
        var /** @type {?} */ control = (this.fg.get(this.model.options.id));
        if (control) {
            this._subscr = control.statusChanges.subscribe(function () {
                _this.model.errorMessage = '';
                if (control.controls) {
                    if (_this.fns.checkAllInvalidAndDirty(/** @type {?} */ (control))) {
                        _this.fns.setModelErrorMessage(_this.fg, _this.model);
                    }
                }
                else {
                    if (control.dirty && control.invalid) {
                        _this.fns.setModelErrorMessage(_this.fg, _this.model);
                    }
                }
            });
        }
    };
    /**
     * @param {?} individual_config
     * @param {?} global_config
     * @return {?}
     */
    NgxBootstrapControlComponent.prototype.mergeWrappersClass = function (individual_config, global_config) {
        // deep clone https://developer.mozilla.org/en/docs/Web/JavaScript/Reference/Global_Objects/Object/assign#Deep_Clone
        var /** @type {?} */ _individual_config = JSON.parse(JSON.stringify(individual_config));
        var /** @type {?} */ _global_config = JSON.parse(JSON.stringify(global_config));
        var /** @type {?} */ just_for_keys = Object.assign(_individual_config, _global_config);
        Object.keys(just_for_keys).map(function (key) {
            var /** @type {?} */ individual_array = individual_config[key] || [];
            var /** @type {?} */ global_array = global_config[key] || [];
            var /** @type {?} */ combined_array = individual_array.concat(global_array.filter(function (item) {
                return individual_array.indexOf(item) < 0;
            }));
            just_for_keys[key] = combined_array;
        });
        return just_for_keys;
    };
    return NgxBootstrapControlComponent;
}());
NgxBootstrapControlComponent.decorators = [
    { type: _angular_core.Component, args: [{
                selector: 'ngx-bootstrap-control',
                template: "<ng-container *ngIf=\"model\" [formGroup]='fg'> <div [class.has-danger]=\"model.errorMessage && model.type!=='group'\" [ngClass]=\"mergedWrappersClass.mainWrapper\" class=\"form-group\"> <label *ngIf=\"model.type!='group'\" for=\"{{model.options.id}}\" [innerHTML]='model.options.label?.html | sanitizeHtml' [ngClass]='mergedWrappersClass.labelWrapper'></label> <div [ngClass]=\"mergedWrappersClass.secondaryWrapper\"> <div [ngClass]=\"mergedWrappersClass.controlWrapper\"> <div *ngIf=\"model.options.prefix\" [innerHTML]=\"model.options.prefix?.html | sanitizeHtml\" [ngClass]='model.options.prefix?.class'></div> <ng-container [ngSwitch]=\"model.type\"> <ng-container *ngSwitchCase=\"'input'\"> <input id=\"{{model.options.id}}\" [formControlName]='model.options.id' [modelEvents]=\"model.options.events\" [modelAttributes]=\"model.options.attributes\" [ngClass]=\"['form-control']\"> </ng-container> <ng-container *ngSwitchCase=\"'textarea'\"> <textarea id=\"{{model.options.id}}\" [formControlName]='model.options.id' [modelEvents]=\"model.options.events\" [modelAttributes]=\"model.options.attributes\" [ngClass]=\"['form-control']\"></textarea> </ng-container> <ng-container *ngSwitchCase=\"'select'\"> <select *ngIf='model.multiple' [multiple]='model.multiple' id=\"{{model.options.id}}\" [formControlName]='model.options.id' [modelEvents]=\"model.options.events\" [modelAttributes]=\"model.options.attributes\" [ngClass]=\"['form-control']\"> <option *ngFor=\"let option of model.options.options\" [value]='option.value' > {{option.label}} </option> </select> <select *ngIf='!model.multiple' id=\"{{model.options.id}}\" [formControlName]='model.options.id' [modelEvents]=\"model.options.events\" [modelAttributes]=\"model.options.attributes\" [ngClass]=\"['form-control']\"> <option *ngFor=\"let option of model.options.options\" [value]='option.value' > {{option.label}} </option> </select> </ng-container> <ng-container *ngSwitchCase=\"'checkbox'\"> <label class=\"form-check-label\"> <input type='checkbox'  [required]='model.options.required' class=\"form-check-input\" id=\"{{model.options.id}}\" [formControlName]='model.options.id' [modelEvents]=\"model.options.events\" [modelAttributes]=\"model.options.attributes\"  [value]=\"model.options.value\"> {{model.options.checkLabel}} </label> </ng-container> <ng-container *ngSwitchCase=\"'radiogroup'\"> <fieldset> <legend [modelAttributes]='model.options.legend?.attributes'> {{model.options.legend?.value}} </legend> <div *ngFor=\"let option of model.options.options\" class='form-check' [class.disabled]='option.disabled' [class.form-check-inline]='model.options.inline'> <label class=\"form-check-label\"> <input type=\"radio\" [formControlName]='model.options.id' class=\"form-check-input\" [value]=\"option.value\" [checked]=\"option.checked\" [attr.disabled]='option.disabled' [modelEvents]=\"model.options.events\" [modelAttributes]=\"option.attributes\"> {{option.label}}  </label> </div> </fieldset> </ng-container> <ng-container *ngSwitchCase=\"'checkboxgroup'\" [formGroupName]='model.options.id'> <div *ngFor=\"let option of model.options.options\" class='form-check' [class.disabled]='option.disabled' [class.form-check-inline]=\"model.options.inline!==false?true:model.options.inline\"> <label class=\"form-check-label\"> <input type='checkbox' class=\"form-check-input\" id=\"{{option.id}}\" [formControlName]='option.id'> {{option.checkLabel}} </label> </div> </ng-container> <!--<div *ngSwitchDefault>output2</div>--> </ng-container> <div *ngIf=\"model.options.suffix\" [innerHTML]=\"model.options.suffix?.html | sanitizeHtml\" [ngClass]='model.options.suffix?.class'></div> </div> <div *ngIf=\"model.errorMessage&& model.type!=='group'\" class='form-control-feedback'>{{model.errorMessage}} </div> </div> </div> <ng-container *ngIf=\"model.type=='group'\" [formGroupName]='model.options.id'> <ngx-bootstrap-control *ngFor=\"let group_model of model.options.group\" [model]='group_model' [fg]='fg.get(model.options.id)' [globalWrappersClass]='globalWrappersClass'> </ngx-bootstrap-control> <div *ngIf=\"model.errorMessage && model.type==='group'\" class=\"form-group\" [ngClass]=\"mergedWrappersClass.mainWrapper\"> <label [ngClass]='mergedWrappersClass.labelWrapper'></label> <div class='has-danger' [ngClass]='mergedWrappersClass.secondaryWrapper'> <div class=\"form-control-feedback\">{{model.errorMessage}}</div> </div> </div> </ng-container> </ng-container>",
                styles: [".form-group { flex-wrap: nowrap; } /*.input-group { width: auto; flex-wrap: wrap; } .wrapper-class { flex: 1 0 auto; } .input-group > .form-control-feedback { width: 100%; } .input-group .form-control:not(:first-child):not(:last-child) { border-top-left-radius: 0; border-top-right-radius: 0.25rem; border-bottom-left-radius: 0; border-bottom-right-radius: 0.25rem; }*/ "],
            },] },
];
/**
 * @nocollapse
 */
NgxBootstrapControlComponent.ctorParameters = function () { return [
    { type: FunctionalService, },
    { type: _angular_core.Renderer2, },
    { type: _angular_core.ElementRef, },
]; };
NgxBootstrapControlComponent.propDecorators = {
    'model': [{ type: _angular_core.Input },],
    'fg': [{ type: _angular_core.Input },],
    'globalWrappersClass': [{ type: _angular_core.Input },],
};

var NgxBootstrapFormComponent = (function () {
    /**
     * @param {?} fs
     * @param {?} fns
     */
    function NgxBootstrapFormComponent(fs, fns) {
        this.fs = fs;
        this.fns = fns;
        this.ngSubmit = new _angular_core.EventEmitter();
        this.ngValueChange = new _angular_core.EventEmitter();
    }
    /**
     * @return {?}
     */
    NgxBootstrapFormComponent.prototype.ngOnInit = function () {
        var _this = this;
        this.form = this.fs.createFormGroup(this.formConfig.models);
        this._subscr = this.form.valueChanges.subscribe(function (data) {
            _this.valueChange();
        });
    };
    /**
     * @return {?}
     */
    NgxBootstrapFormComponent.prototype.ngOnDestroy = function () {
        this._subscr.unsubscribe();
    };
    /**
     * @param {?} f
     * @return {?}
     */
    NgxBootstrapFormComponent.prototype.submit = function (f) {
        this.ngSubmit.emit(f);
        if (this.formConfig.showErrorsOnSubmit !== false) {
            this.fns.setFormErrorMessage(this.form, this.formConfig.models);
        }
    };
    /**
     * @return {?}
     */
    NgxBootstrapFormComponent.prototype.valueChange = function () {
        this.ngValueChange.emit(this.form);
    };
    return NgxBootstrapFormComponent;
}());
NgxBootstrapFormComponent.decorators = [
    { type: _angular_core.Component, args: [{
                selector: 'ngx-bootstrap-form',
                template: "<form [formGroup]='form' (ngSubmit)=\"submit(form);\" [modelAttributes]='formConfig.attributes'> <ngx-bootstrap-control *ngFor=\"let model of formConfig.models\" [model]=\"model\" [fg]=\"form\" [globalWrappersClass]='formConfig.wrappersClass'></ngx-bootstrap-control> <ng-content></ng-content> </form>",
            },] },
];
/**
 * @nocollapse
 */
NgxBootstrapFormComponent.ctorParameters = function () { return [
    { type: FormService, },
    { type: FunctionalService, },
]; };
NgxBootstrapFormComponent.propDecorators = {
    'formConfig': [{ type: _angular_core.Input },],
    'ngSubmit': [{ type: _angular_core.Output },],
    'ngValueChange': [{ type: _angular_core.Output },],
};

var CoreBaseModel = (function () {
    /**
     * @param {?} _options
     */
    function CoreBaseModel(_options) {
        this.options = _options;
    }
    return CoreBaseModel;
}());

var __extends$1 = (undefined && undefined.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var BaseModel = (function (_super) {
    __extends$1(BaseModel, _super);
    /**
     * @param {?} options
     */
    function BaseModel(options) {
        return _super.call(this, options) || this;
    }
    return BaseModel;
}(CoreBaseModel));

var __extends = (undefined && undefined.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var InputModel = (function (_super) {
    __extends(InputModel, _super);
    /**
     * @param {?} options
     */
    function InputModel(options) {
        var _this = _super.call(this, options) || this;
        _this.type = 'input';
        return _this;
    }
    return InputModel;
}(BaseModel));

var __extends$2 = (undefined && undefined.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var GroupModel = (function (_super) {
    __extends$2(GroupModel, _super);
    /**
     * @param {?} options
     */
    function GroupModel(options) {
        var _this = _super.call(this, options) || this;
        _this.type = 'group';
        return _this;
    }
    return GroupModel;
}(BaseModel));

var __extends$3 = (undefined && undefined.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var TextareaModel = (function (_super) {
    __extends$3(TextareaModel, _super);
    /**
     * @param {?} options
     */
    function TextareaModel(options) {
        var _this = _super.call(this, options) || this;
        _this.type = 'textarea';
        return _this;
    }
    return TextareaModel;
}(BaseModel));

var __extends$4 = (undefined && undefined.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var SelectModel = (function (_super) {
    __extends$4(SelectModel, _super);
    /**
     * @param {?} options
     */
    function SelectModel(options) {
        var _this = _super.call(this, options) || this;
        _this.type = 'select';
        _this.multiple = 'multiple';
        if (_this.options.attributes) {
            var _temp_key_1;
            if (Object.keys(_this.options.attributes).some(function (key) {
                _temp_key_1 = key;
                return key.toLocaleLowerCase() === 'multiple';
            })) {
                _this.multiple = _this.options.attributes[_temp_key_1];
                delete _this.options.attributes[_temp_key_1];
            }
            else {
                _this.multiple = '';
            }
        }
        else {
            _this.multiple = '';
        }
        return _this;
    }
    return SelectModel;
}(BaseModel));

var __extends$5 = (undefined && undefined.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var CheckboxModel = (function (_super) {
    __extends$5(CheckboxModel, _super);
    /**
     * @param {?} options
     */
    function CheckboxModel(options) {
        var _this = _super.call(this, options) || this;
        _this.type = 'checkbox';
        return _this;
    }
    return CheckboxModel;
}(BaseModel));

var __extends$6 = (undefined && undefined.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var RadiogroupModel = (function (_super) {
    __extends$6(RadiogroupModel, _super);
    /**
     * @param {?} options
     */
    function RadiogroupModel(options) {
        var _this = _super.call(this, options) || this;
        _this.type = 'radiogroup';
        return _this;
    }
    return RadiogroupModel;
}(BaseModel));

var __extends$7 = (undefined && undefined.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var CheckboxGroupModel = (function (_super) {
    __extends$7(CheckboxGroupModel, _super);
    /**
     * @param {?} options
     */
    function CheckboxGroupModel(options) {
        var _this = _super.call(this, options) || this;
        _this.type = 'checkboxgroup';
        return _this;
    }
    return CheckboxGroupModel;
}(BaseModel));

// export { NgxBootstrapControlComponent } from './uis/bootstrap/components/control/ngx-bootstrap-control.component';
var NgxMyFormModule = (function () {
    function NgxMyFormModule() {
    }
    /**
     * @return {?}
     */
    NgxMyFormModule.forRoot = function () {
        return {
            ngModule: NgxMyFormModule,
            providers: [
                FormService,
                FunctionalService,
            ]
        };
    };
    return NgxMyFormModule;
}());
NgxMyFormModule.decorators = [
    { type: _angular_core.NgModule, args: [{
                imports: [
                    _angular_common.CommonModule,
                    _angular_forms.FormsModule,
                    _angular_forms.ReactiveFormsModule,
                ],
                declarations: [
                    NgxBootstrapControlComponent,
                    NgxBootstrapFormComponent,
                    ModelAttributesDirective,
                    ModelEventsDirective,
                    SanitizeHtmlPipe,
                ],
                exports: [
                    NgxBootstrapControlComponent,
                    NgxBootstrapFormComponent,
                    ModelAttributesDirective,
                    ModelEventsDirective,
                    SanitizeHtmlPipe,
                ]
            },] },
];
/**
 * @nocollapse
 */
NgxMyFormModule.ctorParameters = function () { return []; };

exports.NgxMyFormModule = NgxMyFormModule;
exports.FormService = FormService;
exports.InputModel = InputModel;
exports.GroupModel = GroupModel;
exports.TextareaModel = TextareaModel;
exports.SelectModel = SelectModel;
exports.CheckboxModel = CheckboxModel;
exports.RadiogroupModel = RadiogroupModel;
exports.CheckboxGroupModel = CheckboxGroupModel;
exports.FunctionalService = FunctionalService;
exports.ModelAttributesDirective = ModelAttributesDirective;
exports.ModelEventsDirective = ModelEventsDirective;
exports.SanitizeHtmlPipe = SanitizeHtmlPipe;
exports.NgxBootstrapControlComponent = NgxBootstrapControlComponent;
exports.NgxBootstrapFormComponent = NgxBootstrapFormComponent;

Object.defineProperty(exports, '__esModule', { value: true });

})));
